This function computes the covariance matrix of a log-concave maximum likelihood estimator.
cov.LogConcDEAD(lcd)A matrix equals the covariance matrix of the
log-concave maximum likelihood density estimator.
Object of class "LogConcDEAD" (typically output from
mlelcd)
Yining Chen
Madeleine Cule
Robert Gramacy
Richard Samworth
This function evaluates the covariance matrix of a given log-concave maximum likelihood estimator using the second order partial derivatives of the auxiliary function studied in Cule, M. L. and D\"umbgen, L. (2008).
For examples, see mlelcd.
Cule, M. L. and D\"umbgen, L. (2008) On an auxiliary function for log-density estimation, University of Bern technical report. https://arxiv.org/abs/0807.4719
hatA