print and summary method for objects
of class "LogConcDEAD"## S3 method for class 'LogConcDEAD':
print(x, ...)
## S3 method for class 'LogConcDEAD':
summary(object, ...)"LogConcDEAD" (typically output from
mlelcd), as required by print"LogConcDEAD" (typically output
from mlelcd), as required by summaryprint or summaryprint and summary currently perform the same function.If there has been an error computing the maximum likelihood estimator, an error message is printed.
Otherwise, the value of the log maximum likelihood estimator at observation points is printed. The number of interations required by the subgradient and the number of function evaluations are also printed.
mlelcd